@@ -75,6 +75,37 @@ func TestExifPNG(t *testing.T) {
 	c.Assert(err, qt.Not(qt.IsNil))
 }
 
+func TestIssue8079(t *testing.T) {
+	c := qt.New(t)
+
+	f, err := os.Open(filepath.FromSlash("../../testdata/iss8079.jpg"))
+	c.Assert(err, qt.IsNil)
+	defer f.Close()
+
+	d, err := NewDecoder()
+	c.Assert(err, qt.IsNil)
+	x, err := d.Decode(f)
+	c.Assert(err, qt.IsNil)
+	c.Assert(x.Tags["ImageDescription"], qt.Equals, "Città del Vaticano #nanoblock #vatican #vaticancity")
+}
+
+func TestNullString(t *testing.T) {
+	c := qt.New(t)
+
+	for _, test := range []struct {
+		in     string
+		expect string
+	}{
+		{"foo", "foo"},
+		{"\x20", "\x20"},
+		{"\xc4\x81", "\xc4\x81"}, // \u0101
+		{"\u0160", "\u0160"},     // non-breaking space
+	} {
+		res := nullString([]byte(test.in))
+		c.Assert(res, qt.Equals, test.expect)
+	}
+}
+
 func BenchmarkDecodeExif(b *testing.B) {
 	c := qt.New(b)
 	f, err := os.Open(filepath.FromSlash("../../testdata/sunset.jpg"))
