@@ -18,7 +18,6 @@ package create
 import (
 	"bufio"
 	"bytes"
-	"context"
 	"fmt"
 	"io"
 	"io/ioutil"
@@ -182,20 +181,15 @@ func (c *Client) FromRemote(uri string, options map[string]interface{}) (resourc
 			addUserProvidedHeaders(headers, req)
 		}
 
-		// Workaround for https://github.com/golang/go/issues/49366
-		// This is the entire lifetime of the request.
-		ctx, cancel := context.WithTimeout(req.Context(), 30*time.Second)
-		defer cancel()
-
-		req = req.WithContext(ctx)
-
 		res, err := c.httpClient.Do(req)
 		if err != nil {
 			return nil, err
 		}
 
-		if res.StatusCode < 200 || res.StatusCode > 299 {
-			return nil, errors.Errorf("failed to retrieve remote resource: %s", http.StatusText(res.StatusCode))
+		if res.StatusCode != http.StatusNotFound {
+			if res.StatusCode < 200 || res.StatusCode > 299 {
+				return nil, errors.Errorf("failed to retrieve remote resource: %s", http.StatusText(res.StatusCode))
+			}
 		}
 
 		httpResponse, err := httputil.DumpResponse(res, true)
@@ -215,6 +209,11 @@ func (c *Client) FromRemote(uri string, options map[string]interface{}) (resourc
 		return nil, err
 	}
 
+	if res.StatusCode == http.StatusNotFound {
+		// Not found. This matches how looksup for local resources work.
+		return nil, nil
+	}
+
 	body, err := ioutil.ReadAll(res.Body)
 	if err != nil {
 		return nil, errors.Wrapf(err, "failed to read remote resource %s", uri)
